@@ -15,11 +15,12 @@ import sys
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
 from PyKDE4.kdecore import ki18n, KAboutData, KCmdLineArgs, KCmdLineOptions
-from PyKDE4.kdeui import KApplication, KIcon,  KMessageBox, KGuiItem, KCModule, KWindowSystem
+from PyKDE4.kdeui import KApplication, KIcon,  KMessageBox, KGuiItem, KCModule
 
 from LanguageSelector.LanguageSelector import *
 from LanguageSelector.ImSwitch import ImSwitch
 from QtLanguageSelectorGUI import Ui_QtLanguageSelectorGUI
+from LanguageSelector.LangCache import ExceptionPkgCacheBroken
 from gettext import gettext as i18n
 
 def utf8(str):
@@ -67,7 +68,7 @@ class QtLanguageSelector(KCModule, LanguageSelectorBase):
         except ExceptionPkgCacheBroken:
             s = _("Software database is broken")
             t = _("It is impossible to install or remove any software. "
-                  "Please use the package manager \"Adept\" or run "
+                  "Please use the package manager \"Muon\" or run "
                   "\"sudo apt-get install -f\" in a terminal to fix "
                   "this issue at first.")
             KMessageBox.error(self, t, s)
@@ -233,21 +234,17 @@ class QtLanguageSelector(KCModule, LanguageSelectorBase):
 
         if len(items) == 1:
             li = self._localeinfo.listviewStrToLangInfoMap[unicode(items[0].text())]
-            for (button, langPkg) in (
-              ("checkBoxTr", li.languagePkgList["languagePack"]),
-              ("checkBoxIm", li.languagePkgList["languageSupportInputMethods"]),
-              ("checkBoxSpell", li.languagePkgList["languageSupportWritingAids"]),
-              ("checkBoxFonts", li.languagePkgList["languageSupportFonts"]) ):
-                getattr(self.ui, button).setEnabled(langPkg.available)
-                getattr(self.ui, button).setChecked(False)
-                if langPkg.installed:
-                    getattr(self.ui, button).setChecked(True)
-                    getattr(self.ui, button).setEnabled(False)
-                    getattr(self.ui, button).setToolTip(_("Component already installed"))
-                elif not langPkg.available:
-                    getattr(self.ui, button).setToolTip(_("Component not available"))
-                else:
-                    getattr(self.ui, button).setToolTip(_("Component not installed"))
+            langPkg = li.languagePkgList["languagePack"]
+            self.ui.checkBoxTr.setEnabled(langPkg.available)
+            self.ui.checkBoxTr.setChecked(False)
+            if langPkg.installed:
+                self.ui.checkBoxTr.setChecked(True)
+                self.ui.checkBoxTr.setEnabled(False)
+                self.ui.checkBoxTr.setToolTip(_("Component already installed"))
+            elif not langPkg.available:
+                self.ui.checkBoxTr.setToolTip(_("Component not available"))
+            else:
+                self.ui.checkBoxTr.setToolTip(_("Component not installed"))
         
     def checkInputMethods(self):
         """ check if the selected language has input method support
@@ -287,7 +284,6 @@ class QtLanguageSelector(KCModule, LanguageSelectorBase):
     def onSystemLanguageApply(self):
         (lang, code) = self.getSystemLanguage()
         self.writeSysLanguageSetting(code)
-        self.writeSysLangSetting(code)
         self.updateInputMethods(code)
         KMessageBox.information(self, _("Default system Language now set to %s.") % lang, _("Language Set"))
 
@@ -318,17 +314,12 @@ class QtLanguageSelector(KCModule, LanguageSelectorBase):
         if len(items) == 1:
             elm = items[0]
             li = self._localeinfo.listviewStrToLangInfoMap[unicode(elm.text())]
-#                self._cache.tryInstallLanguage(li.languageCode)
-            for (button, langPkg) in (
-              ("checkBoxTr", li.languagePkgList["languagePack"]),
-              ("checkBoxIm", li.languagePkgList["languageSupportInputMethods"]),
-              ("checkBoxSpell", li.languagePkgList["languageSupportWritingAids"]),
-              ("checkBoxFonts", li.languagePkgList["languageSupportFonts"]) ):
-              if langPkg.available:
+            langPkg = li.languagePkgList["languagePack"]
+            if langPkg.available:
                 if (mode == "install") and (not langPkg.installed):
-                  langPkg.doChange = getattr(self.ui, button).isChecked()
+                    langPkg.doChange = self.ui.checkBoxTr.isChecked()
                 elif (mode == "uninstall") and langPkg.installed:
-                  langPkg.doChange = True
+                    langPkg.doChange = True
             try:
                 self._cache.tryChangeDetails(li)
                 for langPkg in li.languagePkgList.values():
